#include "TXXXMakePhys.h"
#include "Riostream.h"
#include "TH1.h"
#include "TH2.h"
#include "TCutG.h"
#include "snprintf.h"
#include "TGo4WinCond.h"
#include "TGo4PolyCond.h"
#include "TGo4CondArray.h"
#include "TGo4Picture.h"

#include "TXXXEventCal.h"
#include "TXXXEventPhys.h"

//***********************************************************
TXXXMakePhys::TXXXMakePhys() : TGo4EventProcessor("Proc")
{
  cout << "**** TXXXMakePhys: Create instance " << endl;
}
//***********************************************************
TXXXMakePhys::~TXXXMakePhys()
{
  cout << "**** TXXXMakePhys: Delete instance " << endl;
}
//***********************************************************
// this one is used in standard factory
TXXXMakePhys::TXXXMakePhys(const char* name) : TGo4EventProcessor(name)
{
  cout << "**** TXXXMakePhys: Create instance " << name << endl;

  //// init user analysis objects:

// Create of parameters and histograms (check if restored from auto save file):
  fc1x2  = (TH2I *) MakeTH2('I',"Phys/Physc1x2","Crate 1 channel 1x2",200,1,5000,200,1,5000,"Channels","Channels");
  fHis1  = (TH1I *) MakeTH1('I',"Phys/PhysHis1","Channel 1",1000,1,5000,"Channels");
  fHis1g = (TH1I *) MakeTH1('I',"Phys/PhysHis1g","Gated 1",1000,1,5000,"Channels");
  fcHis1 = MakeWinCond("Phys/PhyscHis1",10,20);
  fcHis1->SetValues(200,1000);
  fcHis1->ResetCounts();
  // associate condition with histogram: histogram will be displayed
  // together with condition limits when condition editor is called
  fcHis1->SetHistogram("PhysHis1");
  fcHis1->Enable();
  fcHis1->ResetCounts();
  // Set values of parameter (once we have generated the macros):
  //   gROOT->ProcessLine(".x setcond.C(1,1,1)"); // flags, counters, reset
}
//-----------------------------------------------------------
// event function
Bool_t TXXXMakePhys::BuildEvent(TGo4EventElement * output)
{
  Int_t items,i;

  TXXXEventCal  * input  = (TXXXEventCal *)  GetInputEvent();
  TXXXEventPhys * target = (TXXXEventPhys *) output;
  items = sizeof(target->fPhys1)/sizeof(target->fPhys1[0]);
  for(i = 0; i < items; i++) target->fPhys1[i] = input->fCal1[i];
  items = sizeof(target->fPhys2)/sizeof(target->fPhys2[0]);
  for(i = 0; i < items; i++) target->fPhys2[i] = input->fCal2[i];

  FillHistograms(target); // fill histograms from event
  target->SetValid(kTRUE);
  return kTRUE;
}

//-----------------------------------------------------------
// histogramming function
Bool_t TXXXMakePhys::FillHistograms(TXXXEventPhys * event)
{
  Float_t c0 = (event->fPhys1[0]+event->fPhys1[1])/2;
  fHis1->Fill(c0);                        
  if(fcHis1->Test(c0)) fHis1g->Fill(c0);
  fc1x2->Fill(c0,event->fPhys2[1]);

  return kTRUE;
}
//----------------------------END OF GO4 SOURCE FILE ---------------------
