// This macro setup.C is called in TXXXAnalysis
void setup()
{
  TGo4AnalysisStep        * step;
  TGo4StepFactory         * fact;
  TGo4FileStoreParameter  * store;
  TGo4FileSourceParameter * input;

  Text_t autosave[]="result";   // name of autosave file (.root)
  Text_t UnpOut[]="unpacked";   // name of output file step 1 (.root)
  Text_t CalOut[]="calib";      // name of output file step 2 (.root)
  Text_t PhysOut[]="physics";   // name of output file step 3 (.root)
  Text_t node[]="nodename";     // name of MBS or event server node
  Int_t  port=0;                // depends on the remote event server

  go4->SetAutoSaveFile(autosave); // optional
  go4->SetAutoSaveInterval(0);    // after n seconds , 0 = at end of event loop   
  go4->SetAutoSave(kTRUE);       // optional

  TGo4StepFactory*  facUnp   = new TGo4StepFactory("XXXUnp");
  TGo4AnalysisStep* stepUnp  = new TGo4AnalysisStep("Unpack",facUnp,0,0,0);
  go4->AddAnalysisStep(stepUnp);
  TGo4StepFactory*  facCal   = new TGo4StepFactory("XXXCal");
  TGo4AnalysisStep* stepCal  = new TGo4AnalysisStep("Calib",facCal,0,0,0);
  go4->AddAnalysisStep(stepCal);
  TGo4StepFactory*  facPhys  = new TGo4StepFactory("XXXPhys");
  TGo4AnalysisStep* stepPhys = new TGo4AnalysisStep("Physics",facPhys,0,0,0);
  go4->AddAnalysisStep(stepPhys);

// Analysis has the step, which has the factory, 
// which handles the event processor and event objects

  //=========================================================
  // Set up step 1 Unpack
  //=========================================================
  step = go4->GetAnalysisStep("Unpack");
  fact=(TGo4StepFactory *)step->GetStepFactory();
  fact->DefEventProcessor("XXXMakeUnp","TXXXMakeUnp");
  fact->DefOutputEvent("XXXEventUnp","TXXXEventUnp");

  // activate one of the following MBS event sources:
  //--------------------------------------------------
  TGo4MbsRandomParameter * source = new TGo4MbsRandomParameter("Random");
  //--------------------------------------------------
  // TGo4MbsEventServerParameter * source = new TGo4MbsEventServerParameter(node);
  //--------------------------------------------------
  // TGo4MbsStreamParameter * source = new TGo4MbsStreamParameter(node);
  //--------------------------------------------------
  // TGo4MbsTransportParameter * source = new TGo4MbsTransportParameter(node);
  //--------------------------------------------------
  // TGo4MbsFileParameter * source = new TGo4MbsFileParameter(node);
  //--------------------------------------------------
  // TGo4RevServParameter * source=new TGo4RevServParameter(node);
  // source->SetPort(port);
  //--------------------------------------------------

  step->SetEventSource(source);  // register event source
  step->SetSourceEnabled(kTRUE);
  step->SetProcessEnabled(kTRUE);
  step->SetErrorStopEnabled(kTRUE);
  store = new TGo4FileStoreParameter(UnpOut);
  store->SetOverwriteMode(kTRUE);
  step->SetEventStore(store);
  step->SetStoreEnabled(kFALSE);  // en-disable output

  //=========================================================
  // Set up step 2 Calibrate
  //=========================================================
  step = go4->GetAnalysisStep("Calib");
  fact=(TGo4StepFactory *)step->GetStepFactory();
  fact->DefInputEvent("XXXEventUnp","TXXXEventUnp");
  fact->DefEventProcessor("XXXMakeCal","TXXXMakeCal");
  fact->DefOutputEvent("XXXEventCal","TXXXEventCal");
  input = new TGo4FileSourceParameter(UnpOut);
  step->SetEventSource(input);
  step->SetSourceEnabled(kFALSE);
  step->SetProcessEnabled(kTRUE);
  step->SetErrorStopEnabled(kTRUE);
  store = new TGo4FileStoreParameter(CalOut);
  store->SetOverwriteMode(kTRUE);
  step->SetEventStore(store);
  step->SetStoreEnabled(kFALSE);  // en-disable output

  //=========================================================
  // Set up step 3 Physics
  //=========================================================
  step = go4->GetAnalysisStep("Physics");
  fact=(TGo4StepFactory *)step->GetStepFactory();
  fact->DefInputEvent("XXXEventCal","TXXXEventCal");
  fact->DefEventProcessor("XXXMakePhys","TXXXMakePhys");
  fact->DefOutputEvent("XXXEventPhys","TXXXEventPhys");
  input = new TGo4FileSourceParameter(CalOut);
  step->SetEventSource(input);
  step->SetSourceEnabled(kFALSE);
  step->SetProcessEnabled(kTRUE);
  step->SetErrorStopEnabled(kTRUE);
  store = new TGo4FileStoreParameter(PhysOut);
  store->SetOverwriteMode(kTRUE);
  step->SetEventStore(store);
  step->SetStoreEnabled(kFALSE);  // en-disable output
  printf("Setup done!\n");
}
